pub struct Board {
pub name: String,
pub next_card_id: u32,
pub policies: Policies,
pub sync_branch: Option<String>,
pub nerd_font: bool,
pub created_at: Option<DateTime<Utc>>,
pub columns: Vec<Column>,
}Expand description
The top-level board containing all columns and cards.
Fields
name: Stringnext_card_id: u32policies: Policiessync_branch: Option<String>nerd_font: boolcreated_at: Option<DateTime<Utc>>When the board was created. None for legacy boards.
columns: Vec<Column>Implementations
Sourceimpl Board
impl Board
Sourcepub fn next_card_id(&mut self) -> String
pub fn next_card_id(&mut self) -> String
Generate the next card ID and increment the counter.
Sourcepub fn find_card(&self, card_id: &str) -> Option<(usize, usize)>
pub fn find_card(&self, card_id: &str) -> Option<(usize, usize)>
Find which column a card is in and its index.
Sourcepub fn move_card(&mut self, from_col: usize, card_idx: usize, to_col: usize)
pub fn move_card(&mut self, from_col: usize, card_idx: usize, to_col: usize)
Move a card from one column to another.
Collect all unique tags across the board with counts.
Sourcepub fn all_assignees(&self) -> Vec<(String, usize)>
pub fn all_assignees(&self) -> Vec<(String, usize)>
Collect all unique assignees across all cards, with counts.