pub fn pull(state: &mut SyncState, kando_dir: &Path) -> SyncStatusExpand description
Pull latest changes from remote into shadow, then copy .kando/ to working dir.
pub fn pull(state: &mut SyncState, kando_dir: &Path) -> SyncStatusPull latest changes from remote into shadow, then copy .kando/ to working dir.